# How to make a release

1) Make changes
1) Increment version in setup.py
1) Commit to master
1) Clean up with `make clean`
1) Publish to testpypi with `make publish-test`
1) Publish to pypi with `make publish-live`

